@@ -30,6 +30,10 @@ Submit button form field.
 
 =head1 METHODS
 
+=head1 non_block
+
+See L<HTML::FormFu::Elements::_Field/non_block> for details.
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
